#
# spec file for package python-pycrdt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pycrdt
Version:        0.8.17
Release:        1.1
Summary:        Python bindings for Yrs
License:        MIT
URL:            https://github.com/jupyter-server/pycrdt
Source0:        pycrdt-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module maturin >= 1.4.0}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 7.4.2 with %python-pytest < 8}
#BuildRequires: %%{python_module pydantic >= 2.5.2 with %%python-pydantic < 3}
BuildRequires:  %{python_module y-py >= 0.7.0~a1}
BuildRequires:  %{python_module objsize}
# /SECTION
%python_subpackages

%description
Pycrdt is a Python CRDT library that provides bindings for Yrs, the Rust port of the Yjs framework.

Conflict-free Replicated Data Types (CRDTs) allow creating shared documents that can automatically
merge changes made concurrently on different "copies" of the data. When the data lives on different
machines, they make it possible to build distributed systems that work with local data, leaving the
synchronization and conflict resolution with remote data to the CRDT algorithm, which ensures that
all data replicas eventually converge to the same state.

%prep
%autosetup -p1 -n pycrdt-%{version} -a1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# pydantic is too old
%pytest_arch --ignore tests/test_model.py

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/pycrdt
%{python_sitearch}/pycrdt-%{version}.dist-info

%changelog
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.8.17
  * Update yrs 0.18.2 by @davidbrochart in #92
- Releases 0.8.7 to 0.8.16
  * Export Subscription by @davidbrochart in #90
  * Fix possibly undefined _subscriptions by @davidbrochart in #88
  * Remove warning about project not ready for production by
    @davidbrochart in #82
  * Keep subscription references by @davidbrochart in #85
  * Fix doc observe by @davidbrochart in #87
  * Improve Doc.get return value type by @davidbrochart in #80
  * Add Doc.get() by @davidbrochart in #77
  * Add leading underscore to Python files by @davidbrochart in #75
  * Add update property to TransactionEvent by @davidbrochart in
    [#72]
* Mon Jan 22 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.8.6
  * Resolve "Text data type does not delete as expected" by @jbdyn
    in #68
- Releases in Between:
  * Bump yrs, pyo3, maturin
- Release 0.8.3
  * Support nested ReadTransaction by @davidbrochart in #59
  * Fix Map.pop default value handling by @davidbrochart in #60
  * Add contains method by @davidbrochart in #61
  * Support bytes by @davidbrochart in #62
  * Revert PR #58 by @davidbrochart in #63
* Thu Dec 28 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.8.2
- Required by jupyter-collaboration 2 (still incubating phase)
